@@ -28,10 +28,12 @@ def pytest_configure(config):
     PYTEST_HEADER_MODULES['ipyvuetify'] = 'ipyvuetify'
     PYTEST_HEADER_MODULES['ipysplitpanes'] = 'ipysplitpanes'
     PYTEST_HEADER_MODULES['ipygoldenlayout'] = 'ipygoldenlayout'
-    PYTEST_HEADER_MODULES['voila'] = 'voila'
+    PYTEST_HEADER_MODULES['ipypopout'] = 'ipypopout'
+    PYTEST_HEADER_MODULES['solara'] = 'solara'
     PYTEST_HEADER_MODULES['vispy'] = 'vispy'
     PYTEST_HEADER_MODULES['gwcs'] = 'gwcs'
     PYTEST_HEADER_MODULES['asdf'] = 'asdf'
     PYTEST_HEADER_MODULES['stdatamodels'] = 'stdatamodels'
+    PYTEST_HEADER_MODULES['roman_datamodels'] = 'roman_datamodels'
 
     TESTED_VERSIONS['jdaviz'] = __version__
