@@ -1,4 +1,3 @@
-import logging
 import os
 import warnings
 
@@ -6,11 +5,11 @@ import numpy as np
 from astropy import units as u
 from astropy.io import fits
 from astropy.nddata import StdDevUncertainty
-from astropy.time import Time
 from astropy.wcs import WCS
-from specutils import Spectrum1D
+from specutils import Spectrum
 
 from jdaviz.core.custom_units_and_equivs import PIX2, _eqv_flux_to_sb_pixel
+from jdaviz.core.events import SnackbarMessage
 from jdaviz.core.registries import data_parser_registry
 from jdaviz.core.unit_conversion_utils import check_if_unit_is_per_solid_angle
 from jdaviz.utils import standardize_metadata, PRIHDR_KEY, download_uri_to_path
@@ -24,7 +23,8 @@ EXT_TYPES = dict(flux=['flux', 'sci', 'data'],
 
 @data_parser_registry("cubeviz-data-parser")
 def parse_data(app, file_obj, data_type=None, data_label=None,
-               parent=None, cache=None, local_path=None, timeout=None):
+               parent=None, cache=None, local_path=None, timeout=None,
+               specutils_format=None, spectral_axis_index=None):
     """
     Attempts to parse a data file and auto-populate available viewers in
     cubeviz.
@@ -52,6 +52,11 @@ def parse_data(app, file_obj, data_type=None, data_label=None,
         remote requests in seconds (passed to
         `~astropy.utils.data.download_file` or
         `~astroquery.mast.Conf.timeout`).
+    specutils_format : str, optional
+        Optional format string to pass to Spectrum.read(), see
+        https://specutils.readthedocs.io/en/stable/spectrum1d.html#list-of-loaders
+        for valid format strings. Useful for processed files that may not include
+        the original headers with information used to auto-identify.
     """
 
     flux_viewer_reference_name = app._jdaviz_helper._default_flux_viewer_reference_name
@@ -67,10 +72,14 @@ def parse_data(app, file_obj, data_type=None, data_label=None,
     # TODO: this currently only supports fits files. We will want to make this
     #  generic enough to work with other file types (e.g. ASDF). For now, this
     #  supports MaNGA and JWST data.
+    metadata = {}
     if isinstance(file_obj, fits.hdu.hdulist.HDUList):
+        if 'PRIMARY' in file_obj:
+            metadata[PRIHDR_KEY] = standardize_metadata(file_obj['PRIMARY'].header)
+
         try:
             _parse_spectrum1d_3d(
-                app, Spectrum1D.read(file_obj), data_label=data_label,
+                app, Spectrum.read(file_obj, meta=metadata), data_label=data_label,
                 flux_viewer_reference_name=flux_viewer_reference_name,
                 uncert_viewer_reference_name=uncert_viewer_reference_name
             )
@@ -95,50 +104,36 @@ def parse_data(app, file_obj, data_type=None, data_label=None,
 
         with fits.open(file_obj) as hdulist:
             prihdr = hdulist[0].header
+
+            if specutils_format is not None:
+                sc = Spectrum.read(file_obj, format=specutils_format)
+                _parse_spectrum1d_3d(
+                    app, sc, data_label=data_label,
+                    flux_viewer_reference_name=flux_viewer_reference_name,
+                    uncert_viewer_reference_name=uncert_viewer_reference_name
+                )
+                app.get_tray_item_from_name("Spectral Extraction").disabled_msg = ""
+                return
+
             telescop = prihdr.get('TELESCOP', '').lower()
             exptype = prihdr.get('EXP_TYPE', '').lower()
             # NOTE: Alerted to deprecation of FILETYPE keyword from pipeline on 2022-07-08
             # Kept for posterity in for data processed prior to this date. Use EXP_TYPE instead
             filetype = prihdr.get('FILETYPE', '').lower()
-            system = prihdr.get('SYSTEM', '').lower()
             if telescop == 'jwst' and ('ifu' in exptype or
                                        'mrs' in exptype or
                                        filetype == '3d ifu cube'):
-                for ext, viewer_name in (('SCI', flux_viewer_reference_name),
-                                         ('ERR', uncert_viewer_reference_name),
-                                         ('DQ', None)):
-                    data_label = app.return_data_label(file_name, ext)
-
-                    if ext == 'SCI':
-                        sci_ext = data_label
-
-                    # TODO: generalize/centralize this for use in other configs too
-
-                    if parent is not None:
-                        parent_data_label = parent
-                    elif ext == 'DQ':
-                        parent_data_label = sci_ext
-                    else:
-                        parent_data_label = None
-
-                    _parse_jwst_s3d(
-                        app, hdulist, data_label, ext=ext, viewer_name=viewer_name,
-                        flux_viewer_reference_name=flux_viewer_reference_name,
-                        parent=parent_data_label
-                    )
-            elif telescop == 'jwst' and filetype == 'r3d' and system == 'esa-pipeline':
-                for ext, viewer_name in (('DATA', flux_viewer_reference_name),
-                                         ('ERR', uncert_viewer_reference_name),
-                                         ('QUALITY', None)):
-                    data_label = app.return_data_label(file_name, ext)
-                    _parse_esa_s3d(
-                        app, hdulist, data_label, ext=ext, viewer_name=viewer_name,
-                        flux_viewer_reference_name=flux_viewer_reference_name,
-                    )
+                sc = Spectrum.read(file_obj)
+                data_label = app.return_data_label(file_name)
+                _parse_spectrum1d_3d(
+                                    app, sc, data_label=data_label,
+                                    flux_viewer_reference_name=flux_viewer_reference_name,
+                                    uncert_viewer_reference_name=uncert_viewer_reference_name
+                                    )
             else:
                 try:
                     _parse_spectrum1d_3d(
-                        app, Spectrum1D.read(hdulist), data_label=data_label or file_name,
+                        app, Spectrum.read(hdulist), data_label=data_label or file_name,
                         flux_viewer_reference_name=flux_viewer_reference_name,
                         uncert_viewer_reference_name=uncert_viewer_reference_name
                     )
@@ -152,7 +147,7 @@ def parse_data(app, file_obj, data_type=None, data_label=None,
     # If the data types are custom data objects, use explicit parsers. Note
     #  that this relies on the glue-astronomy machinery to turn the data object
     #  into something glue can understand.
-    elif isinstance(file_obj, Spectrum1D) and file_obj.flux.ndim in (1, 3):
+    elif isinstance(file_obj, Spectrum) and file_obj.flux.ndim in (1, 3):
         if file_obj.flux.ndim == 3:
             _parse_spectrum1d_3d(
                 app, file_obj, data_label=data_label,
@@ -166,9 +161,12 @@ def parse_data(app, file_obj, data_type=None, data_label=None,
             )
 
     elif isinstance(file_obj, np.ndarray) and file_obj.ndim == 3:
+        if spectral_axis_index is not None and spectral_axis_index < 0:
+            spectral_axis_index = spectral_axis_index + file_obj.ndim
         _parse_ndarray(app, file_obj, data_label=data_label, data_type=data_type,
                        flux_viewer_reference_name=flux_viewer_reference_name,
-                       uncert_viewer_reference_name=uncert_viewer_reference_name)
+                       uncert_viewer_reference_name=uncert_viewer_reference_name,
+                       spectral_axis_index=spectral_axis_index)
     else:
         raise NotImplementedError(f'Unsupported data format: {file_obj}')
 
@@ -180,7 +178,8 @@ def _get_celestial_wcs(wcs):
 
 def _return_spectrum_with_correct_units(flux, wcs, metadata, data_type=None,
                                         target_wave_unit=None, hdulist=None,
-                                        uncertainty=None, mask=None, apply_pix2=False):
+                                        uncertainty=None, mask=None, apply_pix2=False,
+                                        spectral_axis=None):
     """Upstream issue of WCS not using the correct units for data must be fixed here.
     Issue: https://github.com/astropy/astropy/issues/3658.
 
@@ -188,7 +187,7 @@ def _return_spectrum_with_correct_units(flux, wcs, metadata, data_type=None,
     brightness and `apply_pix2` is True.
     """
     # handle scale factors when they are included in the unit
-    # (has to be done before Spectrum1D creation)
+    # (has to be done before Spectrum creation)
     if not np.isclose(flux.unit.scale, 1, rtol=1e-5):
         flux = flux.to(flux.unit / flux.unit.scale)
 
@@ -196,7 +195,11 @@ def _return_spectrum_with_correct_units(flux, wcs, metadata, data_type=None,
         warnings.filterwarnings(
             'ignore', message='Input WCS indicates that the spectral axis is not last',
             category=UserWarning)
-        sc = Spectrum1D(flux=flux, wcs=wcs, meta=metadata, uncertainty=uncertainty, mask=mask)
+        if spectral_axis is None:
+            sc = Spectrum(flux=flux, wcs=wcs, uncertainty=uncertainty, mask=mask, meta=metadata)
+        else:
+            sc = Spectrum(flux=flux, spectral_axis=spectral_axis,
+                          uncertainty=uncertainty, mask=mask, meta=metadata)
 
     # convert flux and uncertainty to per-pix2 if input is not a surface brightness
     target_flux_unit = None
@@ -282,12 +285,12 @@ def _parse_hdulist(app, hdulist, file_name=None,
             try:
                 flux_unit = u.Unit(hdu.header['BUNIT'])
             except Exception:
-                logging.warning("Invalid BUNIT, using count as data unit")
+                warnings.warn("Invalid BUNIT, using count as data unit", UserWarning)
                 flux_unit = u.count
         elif data_type == 'mask':  # DQ flags have no unit
             flux_unit = u.dimensionless_unscaled
         else:
-            logging.warning("Invalid BUNIT, using count as data unit")
+            warnings.warn("Invalid BUNIT, using count as data unit", UserWarning)
             flux_unit = u.count
 
         flux = hdu.data << flux_unit
@@ -324,121 +327,6 @@ def _parse_hdulist(app, hdulist, file_name=None,
             app._jdaviz_helper._loaded_flux_cube = app.data_collection[data_label]
 
 
-def _parse_jwst_s3d(app, hdulist, data_label, ext='SCI',
-                    viewer_name=None, flux_viewer_reference_name=None,
-                    parent=None):
-    hdu = hdulist[ext]
-    data_type = _get_data_type_by_hdu(hdu)
-
-    # Manually inject MJD-OBS until we can support GWCS, see
-    # https://github.com/spacetelescope/jdaviz/issues/690 and
-    # https://github.com/glue-viz/glue-astronomy/issues/59
-    if ext == 'SCI' and 'MJD-OBS' not in hdu.header:
-        for key in ('MJD-BEG', 'DATE-OBS'):  # Possible alternatives
-            if key in hdu.header:
-                if key.startswith('MJD'):
-                    hdu.header['MJD-OBS'] = hdu.header[key]
-                    break
-                else:
-                    t = Time(hdu.header[key])
-                    hdu.header['MJD-OBS'] = t.mjd
-                    break
-
-    if ext == 'DQ':  # DQ flags have no unit
-        flux = hdu.data << u.dimensionless_unscaled
-    else:
-        unit = u.Unit(hdu.header.get('BUNIT', 'count'))
-        flux = hdu.data << unit
-    wcs = WCS(hdulist['SCI'].header, hdulist)  # Everything uses SCI WCS
-
-    metadata = standardize_metadata(hdu.header)
-
-    # store original WCS in metadata. this is a hacky workaround for converting subsets
-    # to sky regions, where the parent data of the subset might have dropped spatial WCS info
-    metadata['_orig_spatial_wcs'] = _get_celestial_wcs(wcs)
-
-    if hdu.name != 'PRIMARY' and 'PRIMARY' in hdulist:
-        metadata[PRIHDR_KEY] = standardize_metadata(hdulist['PRIMARY'].header)
-
-    data = _return_spectrum_with_correct_units(
-        flux, wcs, metadata, data_type=data_type, hdulist=hdulist)
-    app.add_data(data, data_label, parent=parent)
-
-    # get glue data and update if DQ:
-    if ext == 'DQ':
-        # prevent circular import:
-        from jdaviz.configs.imviz.plugins.parsers import prep_data_layer_as_dq
-
-        data = app.data_collection[-1]
-        prep_data_layer_as_dq(data)
-
-    if data_type == 'flux':  # Forced wave unit conversion made it lose stuff, so re-add
-        app.data_collection[-1].get_component("flux").units = flux.unit
-
-    if viewer_name is not None:
-        app.add_data_to_viewer(viewer_name, data_label)
-
-    if ext == 'DQ':
-        app.add_data_to_viewer(flux_viewer_reference_name, data_label, visible=False)
-
-    if data_type == 'flux':
-        app._jdaviz_helper._loaded_flux_cube = app.data_collection[data_label]
-    elif data_type == 'uncert':
-        app._jdaviz_helper._loaded_uncert_cube = app.data_collection[data_label]
-
-
-def _parse_esa_s3d(app, hdulist, data_label, ext='DATA', flux_viewer_reference_name=None):
-    hdu = hdulist[ext]
-    data_type = _get_data_type_by_hdu(hdu)
-
-    if ext == 'QUALITY':  # QUALITY flags have no unit
-        flux = hdu.data << u.dimensionless_unscaled
-    else:
-        unit = u.Unit(hdu.header.get('BUNIT', 'count'))
-        flux = hdu.data << unit
-
-    hdr = hdulist[1].header
-
-    wcs_dict = {
-        'CTYPE1': 'WAVE    ', 'CUNIT1': 'um', 'CDELT1': hdr['CDELT3'] * 1E6,
-        'CRPIX1': hdr['CRPIX3'],
-        'CRVAL1': hdr['CRVAL3'] * 1E6, 'NAXIS1': hdr['NAXIS3'],
-        'CTYPE2': 'DEC--TAN', 'CUNIT2': 'deg', 'CDELT2': hdr['CDELT1'], 'CRPIX2': hdr['CRPIX1'],
-        'CRVAL2': hdr['CRVAL1'], 'NAXIS2': hdr['NAXIS1'],
-        'CTYPE3': 'RA---TAN', 'CUNIT3': 'deg', 'CDELT3': hdr['CDELT2'], 'CRPIX3': hdr['CRPIX2'],
-        'CRVAL3': hdr['CRVAL2'], 'NAXIS3': hdr['NAXIS2']}
-
-    wcs = WCS(wcs_dict)
-    flux = np.moveaxis(flux, 0, -1)
-    flux = np.swapaxes(flux, 0, 1)
-
-    metadata = standardize_metadata(hdu.header)
-    metadata.update(wcs_dict)  # To be internally consistent
-    if hdu.name != 'PRIMARY' and 'PRIMARY' in hdulist:
-        metadata[PRIHDR_KEY] = standardize_metadata(hdulist['PRIMARY'].header)
-
-    # store original WCS in metadata. this is a hacky workaround for converting subsets
-    # to sky regions, where the parent data of the subset might have dropped spatial WCS info
-    metadata['_orig_spatial_wcs'] = _get_celestial_wcs(wcs)
-
-    data = _return_spectrum_with_correct_units(
-        flux, wcs, metadata, data_type=data_type, hdulist=hdulist)
-
-    app.add_data(data, data_label)
-
-    if data_type == 'flux':  # Forced wave unit conversion made it lose stuff, so re-add
-        app.data_collection[-1].get_component("flux").units = flux.unit
-
-    app.add_data_to_viewer(flux_viewer_reference_name, data_label)
-
-    if data_type == 'flux':
-        app._jdaviz_helper._loaded_flux_cube = app.data_collection[data_label]
-    elif data_type == 'uncert':
-        app._jdaviz_helper._loaded_uncert_cube = app.data_collection[data_label]
-    elif data_type == 'mask':
-        app._jdaviz_helper._loaded_mask_cube = app.data_collection[data_label]
-
-
 def _parse_spectrum1d_3d(app, file_obj, data_label=None,
                          flux_viewer_reference_name=None,
                          uncert_viewer_reference_name=None):
@@ -456,6 +344,7 @@ def _parse_spectrum1d_3d(app, file_obj, data_label=None,
             flux = val << u.dimensionless_unscaled  # DQ flags have no unit
         elif attr == "uncertainty":
             flux = val.represent_as(StdDevUncertainty).quantity
+            flux[np.isinf(flux)] = np.nan  # Avoid INF from IVAR conversion
         else:
             flux = val
 
@@ -492,7 +381,7 @@ def _parse_spectrum1d_3d(app, file_obj, data_label=None,
 
 def _parse_spectrum1d(app, file_obj, data_label=None, spectrum_viewer_reference_name=None):
 
-    # Here 'file_obj' is a Spectrum1D
+    # Here 'file_obj' is a Spectrum
 
     if data_label is None:
         data_label = app.return_data_label(file_obj)
@@ -502,7 +391,7 @@ def _parse_spectrum1d(app, file_obj, data_label=None, spectrum_viewer_reference_
     file_obj.meta['_orig_spatial_wcs'] = _get_celestial_wcs(file_obj.wcs) if hasattr(file_obj, 'wcs') else None  # noqa: E501
 
     # TODO: glue-astronomy translators only look at the flux property of
-    #  specutils Spectrum1D objects. Fix to support uncertainties and masks.
+    #  specutils Spectrum objects. Fix to support uncertainties and masks.
 
     # convert data loaded in flux units to a per-square-pixel surface
     # brightness unit (e.g Jy to Jy/pix**2)
@@ -516,7 +405,8 @@ def _parse_spectrum1d(app, file_obj, data_label=None, spectrum_viewer_reference_
 
 def _parse_ndarray(app, file_obj, data_label=None, data_type=None,
                    flux_viewer_reference_name=None,
-                   uncert_viewer_reference_name=None):
+                   uncert_viewer_reference_name=None,
+                   spectral_axis_index=None):
     if data_label is None:
         data_label = app.return_data_label(file_obj)
 
@@ -531,7 +421,12 @@ def _parse_ndarray(app, file_obj, data_label=None, data_type=None,
         flux = flux << (u.count / PIX2)
 
     meta = standardize_metadata({'_orig_spatial_wcs': None})
-    s3d = Spectrum1D(flux=flux, meta=meta)
+    if spectral_axis_index is None:
+        # Default to last axis in array for the spectral axis
+        msg = "Spectral axis index not specified, assuming last axis."
+        app.hub.broadcast(SnackbarMessage(msg, sender=app._jdaviz_helper, color="warning"))
+        spectral_axis_index = flux.ndim - 1
+    s3d = Spectrum(flux=flux, meta=meta, spectral_axis_index=spectral_axis_index)
 
     # convert data loaded in flux units to a per-square-pixel surface
     # brightness unit (e.g Jy to Jy/pix**2)
@@ -564,7 +459,7 @@ def _parse_gif(app, file_obj, data_label=None, flux_viewer_reference_name=None):
     flux = np.rot90(np.moveaxis(flux, 0, 2), k=-1, axes=(0, 1))
 
     meta = {'filename': file_name, '_orig_spatial_wcs': None}
-    s3d = Spectrum1D(flux=flux * (u.count / PIX2), meta=standardize_metadata(meta))
+    s3d = Spectrum(flux=flux * (u.count / PIX2), meta=standardize_metadata(meta))
 
     app.add_data(s3d, data_label)
     app.add_data_to_viewer(flux_viewer_reference_name, data_label)
