@@ -268,10 +268,11 @@ class SpectralExtraction3D(PluginTemplateMixin, ApertureSubsetSelectMixin,
                 try:
                     self._extract_in_new_instance(subset_lbl=subset_lbl,
                                                   auto_update=True, add_data=True)
-                except Exception:
+                except Exception as e:
                     msg = SnackbarMessage(
                         f"Automatic {self.resulting_product_name} extraction for {subset_lbl} failed",  # noqa
-                        color='error', sender=self, timeout=10000)
+                        color='error', sender=self, timeout=10000,
+                        traceback=e)
                 else:
                     msg = SnackbarMessage(
                         f"Automatic {self.resulting_product_name} extraction for {subset_lbl} successful",  # noqa
@@ -402,7 +403,7 @@ class SpectralExtraction3D(PluginTemplateMixin, ApertureSubsetSelectMixin,
         if self.mask_cube is not None:
             mask_non_science = np.logical_or(self.mask_cube.get_component('flux').data,
                                              mask_non_science)
-        return np.logical_not(mask_non_science).astype(float)
+        return np.logical_not(mask_non_science)
 
     @property
     def aperture_weight_mask(self):
@@ -504,7 +505,10 @@ class SpectralExtraction3D(PluginTemplateMixin, ApertureSubsetSelectMixin,
             wcs = cube.coords
 
         # Filter out NaNs (False = good)
-        mask = np.logical_or(mask, np.isnan(flux))
+        if mask is None:
+            mask = np.isnan(flux)
+        else:
+            mask = np.logical_or(mask, np.isnan(flux))
 
         # Also apply the cube's original mask array
         if mask_cube:
@@ -740,7 +744,8 @@ class SpectralExtraction3D(PluginTemplateMixin, ApertureSubsetSelectMixin,
         except Exception as e:
             self.hub.broadcast(SnackbarMessage(
                 f"Extraction failed: {repr(e)}",
-                sender=self, color="error"))
+                sender=self, color="error",
+                traceback=e))
 
     def vue_create_bg_spec(self, *args, **kwargs):
         self.extract_bg_spectrum(add_data=True)
