@@ -4,7 +4,7 @@ from astropy import units as u
 from astropy.wcs import WCS
 from numpy.testing import assert_allclose
 from regions import PixCoord, CirclePixelRegion, RectanglePixelRegion
-from specutils import Spectrum1D
+from specutils import Spectrum
 
 from jdaviz.core.custom_units_and_equivs import PIX2, SPEC_PHOTON_FLUX_DENSITY_UNITS
 
@@ -36,7 +36,7 @@ def test_basic_unit_conversions(cubeviz_helper, angle_unit):
     # load cube with flux units of MJy
     w, wcs_dict = cubeviz_wcs_dict()
     flux = np.ones((3, 4, 5), dtype=np.float32)
-    cube = Spectrum1D(flux=flux * (u.MJy / angle_unit), wcs=w, meta=wcs_dict)
+    cube = Spectrum(flux=flux * (u.MJy / angle_unit), wcs=w, meta=wcs_dict)
     cubeviz_helper.load_data(cube, data_label="test")
     viewer = cubeviz_helper.app.get_viewer("spectrum-viewer")
 
@@ -45,9 +45,9 @@ def test_basic_unit_conversions(cubeviz_helper, angle_unit):
 
     uc_plg = cubeviz_helper.plugins['Unit Conversion']
     ap_plg = cubeviz_helper.plugins["Aperture Photometry"]._obj
-    label_mouseover = cubeviz_helper.app.session.application._tools['g-coords-info']
+    label_mouseover = cubeviz_helper._coords_info
 
-    cubeviz_helper.load_regions(RectanglePixelRegion(PixCoord(1, 1), 1, 1))
+    cubeviz_helper.plugins['Subset Tools'].import_region(RectanglePixelRegion(PixCoord(1, 1), 1, 1))
     ap_plg.background_selected = "Subset 1"
 
     for flux_unit in SPEC_PHOTON_FLUX_DENSITY_UNITS:
@@ -135,7 +135,7 @@ def test_flux_unit_choices(cubeviz_helper, flux_unit, expected_choices):
     w, wcs_dict = cubeviz_wcs_dict()
     flux = np.zeros((3, 4, 5), dtype=np.float32)
     # load cube in flux_unit, will become cube in flux_unit / pix2
-    cube = Spectrum1D(flux=flux * flux_unit, wcs=w, meta=wcs_dict)
+    cube = Spectrum(flux=flux * flux_unit, wcs=w, meta=wcs_dict)
     cubeviz_helper.load_data(cube)
 
     uc_plg = cubeviz_helper.plugins['Unit Conversion']
@@ -152,11 +152,11 @@ def test_unit_translation(cubeviz_helper, angle_unit):
     w, wcs_dict = cubeviz_wcs_dict()
     flux = np.zeros((30, 20, 3001), dtype=np.float32)
     flux[5:15, 1:11, :] = 1
-    cube = Spectrum1D(flux=flux * u.MJy / angle_unit, wcs=w, meta=wcs_dict)
+    cube = Spectrum(flux=flux * u.MJy / angle_unit, wcs=w, meta=wcs_dict)
     cubeviz_helper.load_data(cube, data_label="test")
 
     center = PixCoord(5, 10)
-    cubeviz_helper.load_regions(CirclePixelRegion(center, radius=2.5))
+    cubeviz_helper.plugins['Subset Tools'].import_region(CirclePixelRegion(center, radius=2.5))
 
     uc_plg = cubeviz_helper.plugins['Unit Conversion']
 
@@ -198,7 +198,7 @@ def test_sb_unit_conversion(cubeviz_helper, angle_unit):
     w, wcs_dict = cubeviz_wcs_dict()
     flux = np.zeros((30, 20, 3001), dtype=np.float32)
     flux[5:15, 1:11, :] = 1
-    cube = Spectrum1D(flux=flux * (u.MJy / angle_unit), wcs=w, meta=wcs_dict)
+    cube = Spectrum(flux=flux * (u.MJy / angle_unit), wcs=w, meta=wcs_dict)
     cubeviz_helper.load_data(cube, data_label="test")
 
     uc_plg = cubeviz_helper.plugins['Unit Conversion']
@@ -222,7 +222,7 @@ def test_sb_unit_conversion(cubeviz_helper, angle_unit):
     uc_plg.flux_unit = 'Jy'
     y_display_unit = u.Unit(viewer_1d.state.y_display_unit)
     assert y_display_unit == u.Jy / angle_unit
-    label_mouseover = cubeviz_helper.app.session.application._tools["g-coords-info"]
+    label_mouseover = cubeviz_helper._coords_info
     flux_viewer = cubeviz_helper.app.get_viewer(
         cubeviz_helper._default_flux_viewer_reference_name
     )
@@ -319,7 +319,7 @@ def test_cubeviz_flux_sb_translation_counts(cubeviz_helper, angle_unit):
     w, wcs_dict = cubeviz_wcs_dict()
     flux = np.zeros((30, 20, 3001), dtype=np.float32)
     flux[5:15, 1:11, :] = 1
-    cube = Spectrum1D(flux=flux * (u.ct / angle_unit), wcs=w, meta=wcs_dict)
+    cube = Spectrum(flux=flux * (u.ct / angle_unit), wcs=w, meta=wcs_dict)
     cubeviz_helper.load_data(cube, data_label="test")
 
     uc_plg = cubeviz_helper.plugins['Unit Conversion']
@@ -345,7 +345,7 @@ def test_cubeviz_flux_sb_translation_counts(cubeviz_helper, angle_unit):
     assert y_display_unit == u.ct / angle_unit
 
     # and test mouseover info
-    label_mouseover = cubeviz_helper.app.session.application._tools["g-coords-info"]
+    label_mouseover = cubeviz_helper._coords_info
     flux_viewer = cubeviz_helper.app.get_viewer(
         cubeviz_helper._default_flux_viewer_reference_name
     )
@@ -371,7 +371,7 @@ def test_limits_on_unit_change(cubeviz_helper, start_unit, end_unit,
     w, wcs_dict = cubeviz_wcs_dict()
     flux = np.zeros((30, 20, 3001), dtype=np.float32)
     flux[5:15, 1:11, :] = 1
-    cube = Spectrum1D(flux=flux * u.Unit(start_unit), wcs=w, meta=wcs_dict)
+    cube = Spectrum(flux=flux * u.Unit(start_unit), wcs=w, meta=wcs_dict)
     cubeviz_helper.load_data(cube, data_label="test")
 
     uc_plg = cubeviz_helper.plugins['Unit Conversion']
