@@ -5,7 +5,7 @@ from glue.config import viewer_tool
 from glue_jupyter.bqplot.image import BqplotImageView
 from glue.viewers.common.tool import CheckableTool
 import numpy as np
-from specutils import Spectrum1D
+from specutils import Spectrum
 
 from jdaviz.core.events import SliceToolStateMessage, SliceSelectSliceMessage
 from jdaviz.core.tools import PanZoom, BoxZoom, _MatchedZoomMixin
@@ -103,7 +103,6 @@ class SpectrumPerSpaxel(ProfileFromCube):
     def deactivate(self):
         for k in ("y_min", "y_max"):
             self._profile_viewer.state.remove_callback(k, self.on_limits_change)
-        self.viewer.stop_stream()
         super().deactivate()
 
     def on_limits_change(self, *args):
@@ -113,7 +112,6 @@ class SpectrumPerSpaxel(ProfileFromCube):
     def on_mouse_move(self, data):
         if data['event'] == 'mouseleave':
             self._mark.visible = False
-            self.viewer.stop_stream()
             self._reset_profile_viewer_bounds()
             self._is_moving = False
             return
@@ -147,30 +145,37 @@ class SpectrumPerSpaxel(ProfileFromCube):
                 return
             cube_data = cube_data[0]
 
-        if isinstance(cube_data, Spectrum1D):
+        if isinstance(cube_data, Spectrum):
             spectrum = cube_data
         else:
             spectrum = cube_data.get_object(statistic=None)
-        # Note: change this when Spectrum1D.with_spectral_axis is fixed.
+        # Note: change this when Spectrum.with_spectral_axis is fixed.
         x_unit = self._profile_viewer.state.x_display_unit
         if spectrum.spectral_axis.unit != x_unit:
             new_spectral_axis = spectrum.spectral_axis.to(x_unit)
-            spectrum = Spectrum1D(spectrum.flux, new_spectral_axis)
+            spectrum = Spectrum(spectrum.flux, new_spectral_axis)
 
-        if x >= spectrum.flux.shape[0] or x < 0 or y >= spectrum.flux.shape[1] or y < 0:
+        if spectrum.spectral_axis_index in [2, -1]:
+            x_ind = 0
+        else:
+            x_ind = 2
+
+        if x >= spectrum.flux.shape[x_ind] or x < 0 or y >= spectrum.flux.shape[1] or y < 0:
             self._reset_profile_viewer_bounds()
             self._mark.visible = False
-            self.viewer.stop_stream()
         else:
-            y_values = spectrum.flux[x, y, :].value
+            if spectrum.spectral_axis_index in [2, -1]:
+                y_values = spectrum.flux[x, y, :].value
+            else:
+                y_values = spectrum.flux[:, y, x].value
             if np.all(np.isnan(y_values)):
                 self._mark.visible = False
                 return
             self._mark.update_xy(spectrum.spectral_axis.value, y_values)
             self._mark.visible = True
 
-            self.viewer.start_stream()
-            self.viewer.update_sonified_cube(x, y)
-
-            self._profile_viewer.set_limits(
-                y_min=np.nanmin(y_values) * 0.8, y_max=np.nanmax(y_values) * 1.2)
+            # Data might have inf too.
+            new_ymin = np.nanmin(y_values)
+            new_ymax = np.nanmax(y_values)
+            if np.all(np.isfinite([new_ymin, new_ymax])):
+                self._profile_viewer.set_limits(y_min=new_ymin * 0.8, y_max=new_ymax * 1.2)
