@@ -6,6 +6,7 @@ from traitlets import Bool, Unicode
 
 from jdaviz.core.registries import tray_registry
 from jdaviz.core.template_mixin import PluginTemplateMixin
+from jdaviz.core.user_api import PluginUserApi
 
 try:
     from jdaviz import __version__
@@ -15,7 +16,8 @@ except ImportError:  # pragma: no cover
 __all__ = ['About']
 
 
-@tray_registry('about', label="About")
+@tray_registry('about', label="About",
+               category='core', sidebar='popup')
 class About(PluginTemplateMixin):
     """Show information about Jdaviz."""
     template_file = __file__, "about.vue"
@@ -29,7 +31,7 @@ class About(PluginTemplateMixin):
         self.jdaviz_version = __version__
 
         # description displayed under plugin title in tray
-        self._plugin_description = 'Information about Jdaviz.'
+        self._plugin_description = 'Information about Jdaviz and links to documentation and resources.'  # noqa
 
         if __version__ != "unknown":
             _ver_pypi = latest_version_from_pypi("jdaviz")
@@ -40,6 +42,17 @@ class About(PluginTemplateMixin):
                 self.jdaviz_pypi = "unknown"
                 self.not_is_latest = False
 
+    def show_popup(self):
+        self.app.force_open_about = True
+
+    @property
+    def user_api(self):
+        if self.config != 'deconfigged':
+            return super().user_api
+        # Deconfigged needs to not show open_in_tray, but instead show_popup
+        expose = ['show_popup']
+        return PluginUserApi(self, expose=expose, in_tray=False)
+
 
 def latest_version_from_pypi(package_name):
     """Version info for given package or `None`."""
