@@ -3,9 +3,11 @@ import numpy as np
 from copy import deepcopy
 
 import astropy.units as u
+from astropy.modeling import fitting
 from specutils import Spectrum
+from specutils.fitting import fit_lines
 from specutils.utils import QuantityModel
-from traitlets import Bool, List, Unicode, observe
+from traitlets import Bool, List, Dict, Any, Unicode, observe
 
 from jdaviz.configs.default.plugins.model_fitting.fitting_backend import fit_model_to_spectrum
 from jdaviz.configs.default.plugins.model_fitting.initializers import (MODELS,
@@ -116,6 +118,12 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
     residuals_label_auto = Bool(True).tag(sync=True)
     residuals_label_invalid_msg = Unicode('').tag(sync=True)
 
+    # fitter options
+    fitter_items = List().tag(sync=True)
+    fitter_selected = Unicode().tag(sync=True)
+    fitter_parameters = Dict().tag(sync=True)
+    fitter_error = Any().tag(sync=True)
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -140,6 +148,30 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
                                                      selected='model_comp_selected',
                                                      manual_options=list(MODELS.keys()))
 
+        # All possible fitter options available with parameters for each.
+        # Parameters with type 'init' are used on initialization and ones
+        # with type 'call' are used on call.
+        self.all_fitters = {
+            'TRFLSQFitter': {'parameters': [{'name': 'maxiter', 'value': 100, 'type': 'call'},
+                                            {'name': 'filter_non_finite', 'value': True, 'type': 'call'},  # noqa
+                                            {'name': 'calc_uncertainties', 'value': True, 'type': 'init'}]},  # noqa
+            'DogBoxLSQFitter': {'parameters': [{'name': 'maxiter', 'value': 100, 'type': 'call'},
+                                               {'name': 'filter_non_finite', 'value': True, 'type': 'call'},  # noqa
+                                               {'name': 'calc_uncertainties', 'value': True, 'type': 'init'}]},  # noqa
+            'LMLSQFitter': {'parameters': [{'name': 'maxiter', 'value': 100, 'type': 'call'},
+                                           {'name': 'filter_non_finite', 'value': True, 'type': 'call'},  # noqa
+                                           {'name': 'calc_uncertainties', 'value': True, 'type': 'init'}]},  # noqa
+            'LevMarLSQFitter': {'parameters': [{'name': 'maxiter', 'value': 100, 'type': 'call'},
+                                               {'name': 'filter_non_finite', 'value': True, 'type': 'call'},  # noqa
+                                               {'name': 'calc_uncertainties', 'value': True, 'type': 'init'}]},  # noqa
+            'LinearLSQFitter': {'parameters': [{'name': 'calc_uncertainties', 'value': True, 'type': 'init'}]},  # noqa
+            'SLSQPLSQFitter': {'parameters': [{'name': 'maxiter', 'value': 100, 'type': 'call'}]},
+            'SimplexLSQFitter': {'parameters': [{'name': 'maxiter', 'value': 100, 'type': 'call'}]}
+        }
+        self.fitter_component = SelectPluginComponent(self, items='fitter_items',
+                                                      selected='fitter_selected',
+                                                      manual_options=list(self.all_fitters.keys()))
+
         if self.config == 'cubeviz':
             # use mean whenever extracting the 1D spectrum of a cube to initialize model params
             self.dataset._spectral_extraction_function = 'Mean'
@@ -172,6 +204,8 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
         self.parallel_n_cpu = None
         if self.config == "deconfigged":
             self.observe_traitlets_for_relevancy(traitlets_to_observe=['dataset_items'])
+        # Update error after all values are initialized
+        self._update_fitter_error()
 
     @property
     def _default_spectrum_viewer_reference_name(self):
@@ -199,7 +233,7 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
                    'add_results', 'residuals_calculate',
                    'residuals']
         expose += ['calculate_fit', 'clear_table', 'export_table',
-                   'fitted_models', 'get_models', 'get_model_parameters']
+                   'fitted_models', 'get_models', 'get_model_parameters', 'fitter_component']
         return PluginUserApi(self, expose=expose)
 
     def _param_units(self, param, model_type=None):
@@ -440,6 +474,36 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
             return
         self.comp_label_invalid_msg = ''
 
+    @observe('fitter_selected')
+    def _update_fitter_component_msg(self, event={}):
+        self.fitter_parameters = self.all_fitters[event['new']]
+        self._update_fitter_error()
+
+    @observe('fitter_parameters')
+    def _update_fitter_parameters(self, event={}):
+        # Update values in all_fitters incase user wants to return to a model
+        # they edited previously
+        self.all_fitters[self.fitter_selected] = self.fitter_parameters
+        self._update_fitter_error()
+
+    def _update_fitter_error(self):
+        kw = {param['name']: param['value'] for param in self.fitter_parameters['parameters']
+              if param['type'] == 'call'}
+        init_kw = {param['name']: param['value'] for param in self.fitter_parameters['parameters']
+                   if param['type'] == 'init'}
+
+        # Try to run specutils fit_lines with current values to see if an error appears
+        try:
+            models_to_fit = self._reinitialize_with_fixed()
+            spec = self.dataset.get_selected_spectrum(use_display_units=True)
+            masked_spectrum = self._apply_subset_masks(spec, self.spectral_subset)
+            fitter = getattr(fitting, self.fitter_component.selected)(**init_kw)
+            fit_lines(masked_spectrum, models_to_fit, fitter=fitter, weights=None,
+                      window=None, **kw)
+            self.fitter_error = None
+        except Exception as e:
+            self.fitter_error = str(e)
+
     def _update_model_equation_default(self):
         self.model_equation_default = '+'.join(cm['id'] for cm in self.component_models)
 
@@ -519,6 +583,7 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
         # update the default label (likely adding the suffix)
         self._update_comp_label_default()
         self._update_model_equation_default()
+        self._update_fitter_error()
 
     def _initialize_model_component(self, model_comp, comp_label, poly_order=None):
         new_model = {"id": comp_label, "model_type": model_comp,
@@ -613,7 +678,8 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
             init_x = masked_spectrum.spectral_axis
             init_y = masked_spectrum.flux
 
-        if init_y.unit != self._units['y']:
+        # do not need to adjust y units if cube_fit is not selected
+        if self.cube_fit and init_y.unit != self._units['y']:
             # equivs for spectral density and flux<>sb
             pixar_sr = masked_spectrum.meta.get('_pixel_scale_factor', 1.0)
             equivs = all_flux_unit_conversion_equivs(pixar_sr, init_x.mean())
@@ -694,16 +760,50 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
 
             else:
                 if unit != uc._obj.sb_unit_selected:
-                    self._units[axis] = uc._obj.sb_unit_selected
+                    unit = uc._obj.sb_unit_selected
                     self._check_model_component_compat([axis], [u.Unit(uc._obj.sb_unit_selected)])
                     return
                 elif msg.axis == 'flux' and uc._obj.has_sb:
                     unit = u.Unit(self.app._get_display_unit('sb'))
 
+        if 'x' in self._units and 'y' in self._units:
+            # Not populated yet on startup
+            previous_x = self._units['x']
+            previous_y = self._units['y']
+
         # update internal tracking of current units
         self._units[axis] = str(unit)
 
+        # Update model component values and units
+        for model in self.component_models:
+            # If we're converting between wavelength and frequency, make the user reestimate
+            # parameters for Linear or Polynomial models because there's no equivalency to convert.
+            if (axis == 'x' and 'x' in self._units and not
+                    u.Unit(self._units['x']).is_equivalent(previous_x)):
+                if model['model_type'] in ('Linear1D', 'Polynomial1D'):
+                    model['compat_display_units'] = False
+                    continue
+
+            for param in model['parameters']:
+                current_quant = param['value']*u.Unit(param['unit'])
+                new_quant = None
+                spectral_axis = self.dataset.selected_obj.spectral_axis
+                # Just need a single spectral axis value to enable spectral_density equivalency
+                equivalencies = all_flux_unit_conversion_equivs(cube_wave=spectral_axis[0])
+                if ((axis == 'y' and param['unit'] == previous_y) or
+                        (axis == 'x' and param['unit'] == previous_x)):
+                    new_quant = flux_conversion_general(current_quant.value,
+                                                        current_quant.unit,
+                                                        self._units[axis],
+                                                        equivalencies=equivalencies)  # noqa
+
+                # Some parameters have units that aren't related to x or y
+                if new_quant is not None:
+                    param['value'] = new_quant.value
+                    param['unit'] = str(new_quant.unit)
+
         self._check_model_component_compat([axis], [unit])
+        self._update_initialized_parameters()
 
     def remove_model_component(self, model_component_label):
         """
@@ -1224,18 +1324,24 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
         masked_spectrum = self._apply_subset_masks(spec,
                                                    self.spectral_subset)
 
+        kw = {param['name']: param['value'] for param in self.fitter_parameters['parameters']
+              if param['type'] == 'call'}
+        init_kw = {param['name']: param['value'] for param in self.fitter_parameters['parameters']
+                   if param['type'] == 'init'}
         try:
             fitted_model, fitted_spectrum = fit_model_to_spectrum(
                 masked_spectrum,
                 models_to_fit,
                 self.model_equation,
+                fitter=getattr(fitting, self.fitter_component.selected)(**init_kw),
                 run_fitter=True,
                 window=None,
                 n_cpu=self.parallel_n_cpu,
+                **kw
             )
-        except AttributeError:
+        except AttributeError as e:
             msg = SnackbarMessage("Unable to fit: model equation may be invalid",
-                                  color="error", sender=self)
+                                  color="error", sender=self, traceback=e)
             self.hub.broadcast(msg)
             return
 
@@ -1248,13 +1354,15 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
 
         if add_data:
             self._fitted_models[self.results_label] = fitted_model
-            self.add_results.add_results_from_plugin(fitted_spectrum)
+            self.add_results.add_results_from_plugin(fitted_spectrum,
+                                                     format='1D Spectrum')
 
             if self.residuals_calculate:
                 # NOTE: this will NOT load into the viewer since we have already called
                 # add_results_from_plugin above.
                 self.add_results.add_results_from_plugin(masked_spectrum-fitted_spectrum,
                                                          label=self.residuals.value,
+                                                         format='1D Spectrum',
                                                          replace=False)
 
         self._set_default_results_label()
@@ -1339,19 +1447,25 @@ class ModelFitting(PluginTemplateMixin, DatasetSelectMixin,
         else:
             spec.mask = spec.mask | np.isnan(spec.flux)
 
+        kw = {param['name']: param['value'] for param in self.fitter_parameters['parameters']
+              if param['type'] == 'call'}
+        init_kw = {param['name']: param['value'] for param in self.fitter_parameters['parameters']
+                   if param['type'] == 'init'}
         try:
             fitted_model, fitted_spectrum = fit_model_to_spectrum(
                 spec,
                 models_to_fit,
                 self.model_equation,
+                fitter=getattr(fitting, self.fitter_component.selected)(**init_kw),
                 run_fitter=True,
                 window=None,
-                n_cpu=self.parallel_n_cpu
+                n_cpu=self.parallel_n_cpu,
+                **kw
             )
-        except ValueError:
+        except ValueError as e:
             snackbar_message = SnackbarMessage(
                 "Cube fitting failed",
-                color='error', loading=False, sender=self)
+                color='error', loading=False, sender=self, traceback=e)
             self.hub.broadcast(snackbar_message)
             raise
 
