@@ -1,9 +1,7 @@
 import os
-import warnings
 import asdf
 import numpy as np
 from astropy import units as u
-from astropy.utils.exceptions import AstropyWarning
 from astropy.io import fits
 from astropy.nddata import NDData
 from astropy.wcs import WCS
@@ -426,13 +424,7 @@ def _jwst2data(file_obj, ext, data_label, try_gwcs_to_fits_sip=False):
 
             # Might have bad GWCS. If so, we exclude it.
             try:
-                # we catch an astropy warning here for non-standard FITS
-                # keywords arising from the FITS SIP approximation. These
-                # warnings don't affect the result, and there's a pending
-                # glue PR with a fix: https://github.com/glue-viz/glue/pull/2540
-                with warnings.catch_warnings():
-                    warnings.simplefilter('ignore', category=AstropyWarning)
-                    data.add_component(component=component, label=comp_label)
+                data.add_component(component=component, label=comp_label)
 
             except Exception:  # pragma: no cover
                 data.coords = None
