@@ -60,7 +60,7 @@ class TestDeleteData(BaseImviz_WCS_WCS):
 
         # We have to remove the data from the viewer before deleting the data from the app.
         self.imviz.app.remove_data_from_viewer("imviz-0", "has_wcs_1[SCI,1]")
-        self.imviz.app.vue_data_item_remove({"item_name": "has_wcs_1[SCI,1]"})
+        self.imviz.app.data_item_remove("has_wcs_1[SCI,1]")
 
         # Make sure we re-linked images 2 and 3 (plus WCS-only reference data layer)
         assert len(self.imviz.app.data_collection.external_links) == 2
@@ -70,13 +70,13 @@ class TestDeleteData(BaseImviz_WCS_WCS):
 
         # Check that the reparenting and coordinate recalculations happened
         assert subset1.subset_state.xatt.parent.label == "Default orientation"
-        assert_allclose(subset1.subset_state.center(), (1.75, 1.75))
+        assert_allclose(subset1.subset_state.center(), (2, 2))
 
         assert subset2.subset_state.xatt.parent.label == "Default orientation"
-        assert_allclose(subset2.subset_state.roi.xmin, -0.25)
-        assert_allclose(subset2.subset_state.roi.ymin, -0.25)
-        assert_allclose(subset2.subset_state.roi.xmax, 1.75)
-        assert_allclose(subset2.subset_state.roi.ymax, 1.75)
+        assert_allclose(subset2.subset_state.roi.xmin, 0, atol=1e-8)
+        assert_allclose(subset2.subset_state.roi.ymin, 0, atol=1e-8)
+        assert_allclose(subset2.subset_state.roi.xmax, 2)
+        assert_allclose(subset2.subset_state.roi.ymax, 2)
 
 
 class TestDeleteWCSLayerWithSubset(BaseImviz_WCS_GWCS):
@@ -98,7 +98,7 @@ class TestDeleteWCSLayerWithSubset(BaseImviz_WCS_GWCS):
         self.imviz.app._change_reference_data("Default orientation")
 
         # Delete N-up E-left reference data from GUI.
-        self.imviz.app.vue_data_item_remove({"item_name": "North-up, East-left"})
+        self.imviz.app.data_item_remove("North-up, East-left")
 
         # Make sure rotated ellipse is still the same as before.
         out_reg_d = self.imviz.app.get_subsets(include_sky_region=True)['Subset 1'][0]['sky_region']
