@@ -1,3 +1,5 @@
+import warnings
+import numpy as np
 import pytest
 from astropy.table import Table
 from astropy.wcs import WCS
@@ -44,14 +46,14 @@ class TestLink_WCS_NoWCS(BaseImviz_WCS_NoWCS, BaseLinkHandler):
 
         # Also check the coordinates display: Last loaded is on top.
 
-        label_mouseover = self.imviz.app.session.application._tools['g-coords-info']
+        label_mouseover = self.imviz._coords_info
         label_mouseover._viewer_mouse_event(self.viewer,
                                             {'event': 'mousemove', 'domain': {'x': 0, 'y': 0}})
 
         assert label_mouseover.as_text() == (
-            'Pixel x=00.3 y=00.2 Value +0.00000e+00',
-            'World 22h30m04.8496s -20d49m59.7490s (ICRS)',
-            '337.5202064976 -20.8332636155 (deg)'
+            'Pixel x=00.0 y=-0.0 Value +0.00000e+00',
+            'World 22h30m04.8674s -20d49m59.9990s (ICRS)',
+            '337.5202808000 -20.8333330600 (deg)'
         )
 
 
@@ -68,7 +70,7 @@ class TestLink_WCS_FakeWCS(BaseImviz_WCS_NoWCS, BaseLinkHandler):
 
         # Also check the coordinates display: Last loaded is on top.
 
-        label_mouseover = self.imviz.app.session.application._tools['g-coords-info']
+        label_mouseover = self.imviz._coords_info
         label_mouseover._viewer_mouse_event(self.viewer,
                                             {'event': 'mousemove',
                                              'domain': {'x': 0, 'y': 0}})
@@ -99,13 +101,13 @@ class TestLink_WCS_WCS(BaseImviz_WCS_WCS, BaseLinkHandler):
         self.viewer.stretch = 'sqrt'
         self.viewer.cuts = (0, 100)
 
-        # Add subsets, both interactive and static.
-        self.imviz._apply_interactive_region('bqplot:truecircle', (1.5, 2.5), (3.6, 4.6))
-        self.imviz.plugins['Subset Tools'].combination_mode = 'new'
+        # Add subsets
         self.imviz.plugins['Subset Tools'].import_region([
+            CirclePixelRegion(center=PixCoord(x=2.55, y=3.55), radius=1.05),
             CirclePixelRegion(center=PixCoord(x=6, y=2), radius=5).to_sky(self.wcs_1),
             PolygonPixelRegion(vertices=PixCoord(x=[1, 2, 2], y=[1, 1, 2])).to_sky(self.wcs_1),
-            PolygonPixelRegion(vertices=PixCoord(x=[2, 3, 3], y=[2, 2, 3])).to_sky(self.wcs_1)])
+            PolygonPixelRegion(vertices=PixCoord(x=[2, 3, 3], y=[2, 2, 3])).to_sky(self.wcs_1)
+        ], combination_mode="new")
 
         # Add markers.
         tbl = Table({'x': (0, 0), 'y': (0, 1)})
@@ -122,10 +124,13 @@ class TestLink_WCS_WCS(BaseImviz_WCS_WCS, BaseLinkHandler):
         all_labels = [layer.layer.label for layer in self.viewer.state.layers]
         # Retrieved subsets as sky regions from Subset plugin, and ensure they
         # match what was loaded and that they are in sky coordinates.
-        subset_as_regions = self.imviz.plugins['Subset Tools'].get_regions()
+        with warnings.catch_warnings():
+            warnings.filterwarnings('ignore',
+                                    message='Regions skipped: MaskedSubset 1, MaskedSubset 2')
+            subset_as_regions = self.imviz.plugins['Subset Tools'].get_regions()
         assert sorted(subset_as_regions) == ['Subset 1', 'Subset 2']
-        assert_allclose(subset_as_regions['Subset 1'].center.ra.deg, 337.519449)
-        assert_allclose(subset_as_regions['Subset 2'].center.ra.deg, 337.518498)
+        assert_allclose(subset_as_regions['Subset 1'].center.ra.deg, 337.519449, rtol=1e-4)
+        assert_allclose(subset_as_regions['Subset 2'].center.ra.deg, 337.518498, rtol=1e-4)
         # ensure agreement between app.get_subsets and subset_tools.get_regions
         ss = self.imviz.app.get_subsets(include_sky_region=True)
         assert ss['Subset 1'][0]['sky_region'] == subset_as_regions['Subset 1']
@@ -151,22 +156,22 @@ class TestLink_WCS_WCS(BaseImviz_WCS_WCS, BaseLinkHandler):
 
         # Also check the coordinates display: Last loaded is on top.
 
-        label_mouseover = self.imviz.app.session.application._tools['g-coords-info']
+        label_mouseover = self.imviz._coords_info
         label_mouseover._viewer_mouse_event(self.viewer,
                                             {'event': 'mousemove',
                                              'domain': {'x': 0, 'y': 0}})
 
         lmtext = label_mouseover.as_text()
-        assert lmtext[0] == 'Pixel x=01.3 y=00.2 Value +1.00000e+00'
-        assert lmtext[1:] == ('World 22h30m04.8496s -20d49m59.7490s (ICRS)',
-                              '337.5202064976 -20.8332636155 (deg)')
+        assert lmtext[0] == 'Pixel x=01.0 y=-0.0 Value +1.00000e+00'
+        assert lmtext[1:] == ('World 22h30m04.8674s -20d49m59.9990s (ICRS)',
+                              '337.5202808000 -20.8333330600 (deg)')
 
         # blink image through clicking with blink tool
         self.viewer.toolbar.active_tool_id = 'jdaviz:blinkonce'
         self.viewer.toolbar.active_tool.on_click({'event': 'click', 'domain': {'x': 0, 'y': 0}})
-        assert label_mouseover.as_text()[0] == 'Pixel x=00.3 y=00.2 Value +1.00000e+00'
-        assert label_mouseover.as_text()[1:] == ('World 22h30m04.8496s -20d49m59.7490s (ICRS)',
-                                                 '337.5202064976 -20.8332636155 (deg)')
+        assert label_mouseover.as_text()[0] == 'Pixel x=00.0 y=-0.0 Value +1.00000e+00'
+        assert label_mouseover.as_text()[1:] == ('World 22h30m04.8674s -20d49m59.9990s (ICRS)',
+                                                 '337.5202808000 -20.8333330600 (deg)')
 
         # Changing link type will raise an error
         with pytest.raises(ValueError, match=".*only be changed after existing subsets are deleted"):  # noqa: E501
@@ -218,15 +223,14 @@ class TestLink_WCS_GWCS(BaseImviz_WCS_GWCS):
                          [-2.697746, 11.137127],
                          [10.148055, 10.554429],
                          [10.439091, -2.170755]], rtol=1e-5)
-        assert_allclose(gwcs_zoom_limits,
-                        [[2.636299, 12.732915],
-                         [13.375281, 5.007547],
-                         [6.300587, -5.126264],
-                         [-4.438394, 2.599103]], rtol=1e-5)
+
+        # this GWCS has a bounding box, and outside of the bounding box will
+        # return nans:
+        assert_allclose(gwcs_zoom_limits, np.nan)
 
         # Also check the coordinates display: Last loaded is on top.
         # Cycle order: GWCS, FITS WCS
-        label_mouseover = self.imviz.app.session.application._tools['g-coords-info']
+        label_mouseover = self.imviz._coords_info
         xy = self.viewer._get_real_xy(self.imviz.app.data_collection[0], 0, 0, reverse=True)
         label_mouseover._viewer_mouse_event(
             self.viewer, {'event': 'mousemove', 'domain': {'x': xy[0], 'y': xy[1]}})
@@ -237,19 +241,22 @@ class TestLink_WCS_GWCS(BaseImviz_WCS_GWCS):
         assert not label_mouseover.row2_unreliable
         assert not label_mouseover.row3_unreliable
 
-        # Make sure GWCS now can extrapolate.
+        # Make sure GWCS does not extrapolate.
         xy = self.viewer._get_real_xy(self.imviz.app.data_collection[1], -1, -1, reverse=True)
         label_mouseover._viewer_mouse_event(
             self.viewer, {'event': 'mousemove', 'domain': {'x': xy[0], 'y': xy[1]}})
-        assert label_mouseover.as_text() == ('Pixel x=-1.0 y=-1.0',
-                                             'World 00h14m19.5829s -30d23m30.9860s (ICRS)',
-                                             '3.5815955408 -30.3919405616 (deg)')
+        assert label_mouseover.as_text() == ('', '', '')
+
         # FITS WCS is reference data and has no concept of bounding box
         # but cursor is outside GWCS bounding box
         assert label_mouseover.row1_unreliable
-        assert label_mouseover.row2_unreliable
         assert label_mouseover.row3_unreliable
 
+        # row2 was "unreliable" when the WCS-only layer used GWCS.
+        # now with FITS WCS as the coordinate frame, there is no bounding
+        # box and row2 is reliable.
+        assert not label_mouseover.row2_unreliable
+
         xy = self.viewer._get_real_xy(self.imviz.app.data_collection[0], 0, 0, reverse=True)
         self.viewer.blink_once()
         label_mouseover._viewer_mouse_event(
@@ -278,29 +285,33 @@ class TestLink_GWCS_GWCS(BaseImviz_GWCS_GWCS):
         self.imviz.link_data(align_by='pixels')
 
         # Check the coordinates display: Last loaded is on top.
-        label_mouseover = self.imviz.app.session.application._tools['g-coords-info']
+        label_mouseover = self.imviz._coords_info
         label_mouseover._viewer_mouse_event(self.viewer,
                                             {'event': 'mousemove', 'domain': {'x': -1, 'y': -1}})
-        assert label_mouseover.as_text() == ('Pixel x=-1.0 y=-1.0',
-                                             'World 00h14m19.5987s -30d23m31.0683s (ICRS)',
-                                             '3.5816611274 -30.3919634282 (deg)')
+        assert label_mouseover.as_text() == ('Pixel x=-1.0 y=-1.0', '', '')
         assert not label_mouseover.row1_unreliable
-        assert label_mouseover.row2_unreliable
         assert label_mouseover.row3_unreliable
 
+        # `row2_unreliable` was True when the WCS-only layer used GWCS.
+        # now with FITS WCS as the coordinate frame, there is no bounding
+        # box and row2 is reliable.
+        assert not label_mouseover.row2_unreliable
+
         # Back to reference image with bounds check.
         label_mouseover._viewer_mouse_event(self.viewer,
                                             {'event': 'keydown', 'key': 'b',
                                              'domain': {'x': -1, 'y': -1}})
         self.viewer.on_mouse_or_key_event({'event': 'keydown', 'key': 'b',
                                            'domain': {'x': -1, 'y': -1}})
-        assert label_mouseover.as_text() == ('Pixel x=-1.0 y=-1.0',
-                                             'World 00h14m19.5829s -30d23m30.9860s (ICRS)',
-                                             '3.5815955408 -30.3919405616 (deg)')
+        assert label_mouseover.as_text() == ('Pixel x=-1.0 y=-1.0', '', '')
         assert not label_mouseover.row1_unreliable
-        assert label_mouseover.row2_unreliable
         assert label_mouseover.row3_unreliable
 
+        # row2 was "unreliable" when the WCS-only layer used GWCS.
+        # now with FITS WCS as the coordinate frame, there is no bounding
+        # box and row2 is reliable.
+        assert not label_mouseover.row2_unreliable
+
 
 def test_imviz_no_data(imviz_helper):
     refdata, iref = get_reference_image_data(imviz_helper.app)
