@@ -1,11 +1,10 @@
 import bqplot
-import numpy as np
 from astropy import units as u
 from astropy.coordinates import Angle, SkyCoord
-from regions import PolygonSkyRegion
 from traitlets import Bool
 
 from jdaviz.core.events import SnackbarMessage
+from jdaviz.core.region_translators import stcs_string2region
 from jdaviz.core.registries import tray_registry
 from jdaviz.core.template_mixin import PluginTemplateMixin
 
@@ -15,23 +14,21 @@ __all__ = ['SlitOverlay', 'jwst_header_to_skyregion']
 def jwst_header_to_skyregion(header):
     """Convert S_REGION in given FITS header for JWST data into sky region."""
     s_region = header['S_REGION']
-    footprint = s_region.split("POLYGON ICRS")[1].split()
-    ra = np.array(footprint[::2], dtype=float)
-    dec = np.array(footprint[1::2], dtype=float)
-    corners = SkyCoord(ra, dec, unit="deg")
-    skyregion = PolygonSkyRegion(corners)
+    skyregion = stcs_string2region(s_region)
+
+    corners = skyregion.vertices
+    ra, dec = corners.ra.degree, corners.dec.degree
 
     # Need these for zooming
     length = corners[0].separation(corners[1])
     width = corners[1].separation(corners[2])
     skyregion.height = Angle(max(length, width), u.deg)
-    skyregion.center = SkyCoord(ra.mean(), dec.mean(), unit="deg")
+    skyregion.center = SkyCoord(ra.mean(), dec.mean(), unit=u.deg)
 
     return skyregion
 
 
-@tray_registry('g-slit-overlay', label="Slit Overlay",
-               viewer_requirements=['table', 'image', 'spectrum-2d', 'spectrum'])
+@tray_registry('g-slit-overlay', label="Slit Overlay")
 class SlitOverlay(PluginTemplateMixin):
     template_file = __file__, "slit_overlay.vue"
     visible = Bool(True).tag(sync=True)
