@@ -402,7 +402,7 @@ class LineAnalysis(PluginTemplateMixin, DatasetSelectMixin, TableMixin,
                         # user
                         self.hub.broadcast(SnackbarMessage(
                             f"failed to calculate line analysis statistics: {e}", sender=self,
-                            color="warning"))
+                            color="warning", traceback=e))
                         self.update_results(None)
                         return
 
@@ -437,7 +437,7 @@ class LineAnalysis(PluginTemplateMixin, DatasetSelectMixin, TableMixin,
                         # user
                         self.hub.broadcast(SnackbarMessage(
                             f"failed to calculate line analysis statistics: {e}", sender=self,
-                            color="warning"))
+                            color="warning", traceback=e))
                         self.update_results(None)
                         return
                     # When flux is equivalent to Jy, lineflux result should be shown in W/m2
@@ -474,15 +474,7 @@ class LineAnalysis(PluginTemplateMixin, DatasetSelectMixin, TableMixin,
                 temp_result = FUNCTIONS[function](spec_subtracted, region=None)
                 self.results_centroid = temp_result.to_value(u.AA, equivalencies=u.spectral())
             else:
-                # if the minimum flux is negative, translate the spectrum until it is
-                # non-negative for the these line analysis functions:
-                if spec_subtracted.flux.min() < 0:
-                    spec_subtracted_nonneg_flux = (
-                            spec_subtracted - np.min((spectrum - continuum).flux)
-                    )
-                else:
-                    spec_subtracted_nonneg_flux = spec_subtracted
-                temp_result = FUNCTIONS[function](spec_subtracted_nonneg_flux)
+                temp_result = FUNCTIONS[function](spec_subtracted)
 
             temp_result = coerce_unit(temp_result)
             temp_results.append({'function': function,
