@@ -5,12 +5,13 @@ from astropy.table import QTable
 from astropy.tests.helper import assert_quantity_allclose
 from numpy.testing import assert_allclose
 from regions import RectanglePixelRegion, PixCoord
-from specutils import Spectrum1D, SpectralRegion
+from specutils import Spectrum, SpectralRegion
+from glue.core.roi import XRangeROI
 
-from jdaviz.configs.specviz.plugins.line_analysis.line_analysis import _coerce_unit
 from jdaviz.core.custom_units_and_equivs import PIX2
 from jdaviz.core.events import LineIdentifyMessage
 from jdaviz.core.marks import LineAnalysisContinuum
+from jdaviz.core.unit_conversion_utils import coerce_unit
 
 
 def test_plugin(specviz_helper, spectrum1d):
@@ -34,18 +35,20 @@ def test_plugin(specviz_helper, spectrum1d):
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
     specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6500 * unit,
                                                                         7400 * unit))
-    specviz_helper.app.state.drawer = True
+    specviz_helper.app.state.drawer_content = 'plugins'
 
     assert 'Subset 1' in plugin.spectral_subset.labels
     plugin.selected_subset = 'Subset 1'
     plugin.selected_continuum = 'Surrounding'
     plugin.width = 3
 
-    for result_dict in plugin.results:
+    for result_dict in plugin.get_results():
         if result_dict in ['Line Flux']:
             # should have an assigned uncertainty (with min required version of specutils)
             assert len(result_dict.get('uncertainty')) > 0
 
+    assert len(plugin.table) == 1
+
 
 @pytest.mark.filterwarnings(r"ignore:'W/m2/m' contains multiple slashes")
 @pytest.mark.filterwarnings('ignore:No observer defined on WCS')
@@ -66,7 +69,7 @@ def test_spatial_subset(cubeviz_helper, image_cube_hdu_obj):
     cubeviz_helper.plugins['Subset Tools'].combination_mode = 'new'
     cubeviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(3.623e-7 * unit,
                                                                         3.627e-7 * unit))
-    cubeviz_helper.app.state.drawer = True
+    cubeviz_helper.app.state.drawer_content = 'plugins'
 
     plugin = cubeviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
     plugin.keep_active = True
@@ -76,7 +79,7 @@ def test_spatial_subset(cubeviz_helper, image_cube_hdu_obj):
     plugin.continuum_subset_selected = 'Surrounding'
     plugin.width = 1
 
-    for result in plugin.results:
+    for result in plugin.get_results():
         # Check that there exists a value
         assert not np.isnan(float(result['result']))
         # Check the unit is not dimensionless
@@ -104,13 +107,50 @@ def test_cubeviz_units(cubeviz_helper, spectrum1d_cube_custom_fluxunit,
     plugin.dataset_selected = 'Spectrum (sum)'
     plugin.continuum_subset_selected = 'Surrounding'
 
-    results = plugin.results
+    results = plugin.get_results()
     assert results[0]['unit'] == 'W / m2'
 
+    viewer = cubeviz_helper.app.get_viewer('spectrum-viewer')
+    viewer.apply_roi(XRangeROI(4.63e-7, 4.64e-7))
+
+    la = cubeviz_helper.plugins['Line Analysis']
+    la.keep_active = True
+    la.spectral_subset.selected = 'Subset 1'
+
+    marks_before = [la._obj.continuum_marks['left'].marks_list[0].y,
+                    la._obj.continuum_marks['right'].marks_list[0].y]
+
+    # change flux unit and make sure result stays the same after conversion
+    uc.flux_unit.selected = 'MJy'
+
+    marks_after = [la._obj.continuum_marks['left'].marks_list[0].y,
+                   la._obj.continuum_marks['right'].marks_list[0].y]
+
+    # ensure continuum marks update when spectral_y is changed by
+    # multiply converted continuum marks by expected scale factor (MJy -> Jy)
+    scaling_factor = 1e-6
+    assert_allclose([mark * scaling_factor for mark in marks_before], marks_after, rtol=1e-5)
+
+    # reset to test again after spectral_y_type is changed
+    marks_before = marks_after
+
     # now change to surface brightness
     uc.spectral_y_type = 'Surface Brightness'
 
-    results = plugin.results
+    if sq_angle_unit == PIX2:
+        # translation does not alter spectral_y values in viewer
+        scaling_factor = 1
+    else:
+        scaling_factor = cube.meta.get('PIXAR_SR')
+
+    marks_after = [la._obj.continuum_marks['left'].marks_list[0].y,
+                   la._obj.continuum_marks['right'].marks_list[0].y]
+
+    # ensure continuum marks update when spectral_y_type is changed
+    # multiply converted continuum marks by expected pixel scale factor
+    assert_allclose([mark / scaling_factor for mark in marks_before], marks_after, rtol=1e-5)
+
+    results = plugin.get_results()
     line_flux_before_unit_conversion = results[0]
     # convert back and forth between unit<>str for string format consistency
     unit_str = u.Unit(f'W / {sq_angle_unit.to_string()} m2').to_string()
@@ -118,7 +158,7 @@ def test_cubeviz_units(cubeviz_helper, spectrum1d_cube_custom_fluxunit,
 
     # change flux unit and make sure result stays the same after conversion
     uc.flux_unit.selected = 'MJy'
-    results = plugin.results
+    results = plugin.get_results()
     np.testing.assert_allclose(float(results[0]['result']),
                                float(line_flux_before_unit_conversion['result']))
     np.testing.assert_allclose(float(results[0]['uncertainty']),
@@ -168,7 +208,7 @@ def test_line_identify(specviz_helper, spectrum1d):
 
     ll_plugin = specviz_helper.app.get_tray_item_from_name('g-line-list')
     la_plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
-    la_plugin.plugin_opened = True
+    la_plugin.get_results()
     rest_names = [line['name_rest'] for line in ll_plugin.list_contents['Test List']['lines']]
 
     # will default to no selection
@@ -224,11 +264,11 @@ def test_coerce_unit():
     q_input = 1 * u.Unit('1E-20 erg m / (Angstrom cm**2 s)')
     q_input.uncertainty = 0.1 * u.Unit('1E-20 erg m / (Angstrom cm**2 s)')
     q_unit = u.Unit('erg / (cm**2 s)')
-    q_coerced = _coerce_unit(q_input)
+    q_coerced = coerce_unit(q_input)
     assert_quantity_allclose(q_coerced, 1e-10 * q_unit)
     assert_quantity_allclose(q_coerced.uncertainty, 1e-11 * q_unit)
     q_input.uncertainty = None
-    q_coerced = _coerce_unit(q_input)
+    q_coerced = coerce_unit(q_input)
     assert not hasattr(q_coerced, 'uncertainty')
 
 
@@ -249,7 +289,7 @@ def test_continuum_surrounding_spectral_subset(specviz_helper, spectrum1d):
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
     specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6500 * unit,
                                                                         7400 * unit))
-    specviz_helper.app.state.drawer = True
+    specviz_helper.app.state.drawer_content = 'plugins'
 
     plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
     assert 'Subset 1' in plugin.spectral_subset.labels
@@ -258,7 +298,7 @@ def test_continuum_surrounding_spectral_subset(specviz_helper, spectrum1d):
     plugin.width = 3
 
     # Values have not yet been validated
-    np.testing.assert_allclose(float(plugin.results[0]['result']), 2.153181e-13, atol=1e-15)
+    np.testing.assert_allclose(float(plugin.get_results()[0]['result']), 2.153181e-13, atol=1e-15)
 
 
 def test_continuum_spectral_same_value(specviz_helper, spectrum1d):
@@ -278,7 +318,7 @@ def test_continuum_spectral_same_value(specviz_helper, spectrum1d):
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
     specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6500 * unit,
                                                                         7400 * unit))
-    specviz_helper.app.state.drawer = True
+    specviz_helper.app.state.drawer_content = 'plugins'
 
     plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
     assert 'Subset 1' in plugin.spectral_subset.labels
@@ -287,7 +327,7 @@ def test_continuum_spectral_same_value(specviz_helper, spectrum1d):
     plugin.width = 3
 
     # continuum and spectral cannot be the same value
-    assert plugin.results[0]['result'] == ''
+    assert plugin.get_results()[0]['result'] == ''
 
 
 def test_continuum_surrounding_invalid_width(specviz_helper, spectrum1d):
@@ -307,14 +347,14 @@ def test_continuum_surrounding_invalid_width(specviz_helper, spectrum1d):
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
     specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6500 * unit,
                                                                         7400 * unit))
-    specviz_helper.app.state.drawer = True
+    specviz_helper.app.state.drawer_content = 'plugins'
 
     plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
     assert 'Subset 1' in plugin.spectral_subset.labels
     plugin.continuum_subset_selected = 'Surrounding'
     plugin.spectral_subset_selected = 'Subset 1'
     plugin.continuum_width = 11
-    assert plugin.results[0]['result'] == ''
+    assert plugin.get_results()[0]['result'] == ''
 
 
 def test_continuum_subset_spectral_entire(specviz_helper, spectrum1d):
@@ -334,7 +374,7 @@ def test_continuum_subset_spectral_entire(specviz_helper, spectrum1d):
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
     specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6500 * unit,
                                                                         7400 * unit))
-    specviz_helper.app.state.drawer = True
+    specviz_helper.app.state.drawer_content = 'plugins'
 
     plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
     assert 'Subset 1' in plugin.spectral_subset.labels
@@ -343,7 +383,7 @@ def test_continuum_subset_spectral_entire(specviz_helper, spectrum1d):
     plugin.width = 3
 
     # Values have not yet been validated
-    np.testing.assert_allclose(float(plugin.results[0]['result']), -2.79572e-13, atol=1e-15)
+    np.testing.assert_allclose(float(plugin.get_results()[0]['result']), -2.79572e-13, atol=1e-15)
 
 
 def test_continuum_subset_spectral_subset2(specviz_helper, spectrum1d):
@@ -363,12 +403,12 @@ def test_continuum_subset_spectral_subset2(specviz_helper, spectrum1d):
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
     specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6200 * unit,
                                                                         7000 * unit))
-    specviz_helper.app.state.drawer = True
+    specviz_helper.app.state.drawer_content = 'plugins'
 
     specviz_helper.plugins['Subset Tools'].combination_mode = 'new'
     specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(7100 * unit,
                                                                         7700 * unit))
-    specviz_helper.app.state.drawer = True
+    specviz_helper.app.state.drawer_content = 'plugins'
 
     plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
     assert plugin.spectral_subset.labels == ['Entire Spectrum', 'Subset 1', 'Subset 2']
@@ -378,7 +418,7 @@ def test_continuum_subset_spectral_subset2(specviz_helper, spectrum1d):
     plugin.width = 3
 
     # Values have not yet been validated
-    np.testing.assert_allclose(float(plugin.results[0]['result']), 1.482418e-14, atol=1e-16)
+    np.testing.assert_allclose(float(plugin.get_results()[0]['result']), 1.482418e-14, atol=1e-16)
 
 
 def test_continuum_surrounding_no_right(specviz_helper, spectrum1d):
@@ -398,7 +438,7 @@ def test_continuum_surrounding_no_right(specviz_helper, spectrum1d):
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
     specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6500 * unit,
                                                                         8000 * unit))
-    specviz_helper.app.state.drawer = True
+    specviz_helper.app.state.drawer_content = 'plugins'
 
     plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
     assert 'Subset 1' in plugin.spectral_subset.labels
@@ -408,7 +448,7 @@ def test_continuum_surrounding_no_right(specviz_helper, spectrum1d):
     plugin.width = 3
 
     # Values have not yet been validated
-    np.testing.assert_allclose(float(plugin.results[0]['result']), 4.204513e-14, atol=1e-16)
+    np.testing.assert_allclose(float(plugin.get_results()[0]['result']), 4.204513e-14, atol=1e-16)
 
 
 def test_continuum_surrounding_no_left(specviz_helper, spectrum1d):
@@ -428,7 +468,7 @@ def test_continuum_surrounding_no_left(specviz_helper, spectrum1d):
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
     specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6000 * unit,
                                                                         7500 * unit))
-    specviz_helper.app.state.drawer = True
+    specviz_helper.app.state.drawer_content = 'plugins'
 
     plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
     assert 'Subset 1' in plugin.spectral_subset.labels
@@ -438,7 +478,7 @@ def test_continuum_surrounding_no_left(specviz_helper, spectrum1d):
     plugin.width = 3
 
     # Values have not yet been validated
-    np.testing.assert_allclose(float(plugin.results[0]['result']), 7.570859e-14, atol=1e-16)
+    np.testing.assert_allclose(float(plugin.get_results()[0]['result']), 7.570859e-14, atol=1e-16)
 
 
 def test_subset_changed(specviz_helper, spectrum1d):
@@ -458,7 +498,7 @@ def test_subset_changed(specviz_helper, spectrum1d):
     unit = u.Unit(specviz_helper.plugins['Unit Conversion'].spectral_unit.selected)
     specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6000 * unit,
                                                                         7500 * unit))
-    specviz_helper.app.state.drawer = True
+    specviz_helper.app.state.drawer_content = 'plugins'
 
     plugin = specviz_helper.app.get_tray_item_from_name('specviz-line-analysis')
     assert 'Subset 1' in plugin.spectral_subset.labels
@@ -468,11 +508,12 @@ def test_subset_changed(specviz_helper, spectrum1d):
     plugin.width = 3
 
     specviz_helper.plugins['Subset Tools'].import_region(SpectralRegion(6500 * unit,
-                                                                        7500 * unit))
-    specviz_helper.app.state.drawer = True
+                                                                        7500 * unit),
+                                                         edit_subset='Subset 1')
+    specviz_helper.app.state.drawer_content = 'plugins'
 
     # Values have not yet been validated
-    np.testing.assert_allclose(float(plugin.results[0]['result']), 2.153181e-13, atol=1e-15)
+    np.testing.assert_allclose(float(plugin.get_results()[0]['result']), 2.153181e-13, atol=1e-15)
 
 
 def test_invalid_subset(specviz_helper, spectrum1d):
@@ -480,8 +521,8 @@ def test_invalid_subset(specviz_helper, spectrum1d):
     specviz_helper.load_data(spectrum1d, data_label="right_spectrum")
 
     # 5000-7000
-    sp2 = Spectrum1D(spectral_axis=spectrum1d.spectral_axis - 1000*spectrum1d.spectral_axis.unit,
-                     flux=spectrum1d.flux * 1.25)
+    sp2 = Spectrum(spectral_axis=spectrum1d.spectral_axis - 1000*spectrum1d.spectral_axis.unit,
+                   flux=spectrum1d.flux * 1.25)
     specviz_helper.load_data(sp2, data_label="left_spectrum")
 
     # apply subset that overlaps on left_spectrum, but not right_spectrum
