@@ -1,4 +1,6 @@
-from specutils import Spectrum1D
+import pytest
+from specutils import Spectrum
+
 from jdaviz import Specviz
 
 
@@ -10,9 +12,11 @@ def test_helper(specviz2d_helper, mos_spectrum2d):
 
     returned_data = specviz2d_helper.get_data("Spectrum 2D")
     assert len(returned_data.shape) == 1
-    assert isinstance(returned_data, Spectrum1D)
+    assert isinstance(returned_data, Spectrum)
 
 
+# Some API might be going through deprecation, so ignore the warning.
+@pytest.mark.filterwarnings("ignore::DeprecationWarning")
 def test_plugin_user_apis(specviz2d_helper):
     for plugin_name, plugin_api in specviz2d_helper.plugins.items():
         plugin = plugin_api._obj
