@@ -11,8 +11,10 @@ import pytest
 from astropy import units as u
 from astropy.io import fits
 from astropy.nddata import CCDData, StdDevUncertainty
+from astropy.table import Table
 from astropy.wcs import WCS
 from specutils import Spectrum, SpectrumCollection, SpectrumList
+from astropy.utils.masked import Masked
 
 from jdaviz import __version__, Cubeviz, Imviz, Mosviz, Specviz, Specviz2d, Rampviz, App
 from jdaviz.configs.imviz.tests.utils import (create_wfi_image_model,
@@ -21,6 +23,13 @@ from jdaviz.configs.imviz.tests.utils import (create_wfi_image_model,
                                               _image_nddata_wcs)
 from jdaviz.configs.imviz.plugins.parsers import HAS_ROMAN_DATAMODELS
 from jdaviz.utils import NUMPY_LT_2_0
+from jdaviz.core.loaders.importers.spectrum_list.spectrum_list import (
+    SpectrumListImporter,
+    SpectrumListConcatenatedImporter
+)
+from jdaviz.core.registries import loader_importer_registry
+from jdaviz.core.template_mixin import PluginTemplateMixin
+from jdaviz.core.registries import tray_registry
 
 if not NUMPY_LT_2_0:
     np.set_printoptions(legacy="1.25")
@@ -28,6 +37,83 @@ if not NUMPY_LT_2_0:
 SPECTRUM_SIZE = 10  # length of spectrum
 
 
+@pytest.fixture
+def fake_classes_in_registries():
+    """
+    This fixture is meant to be used in cases where a test
+    needs to check items in the registry. It provides a
+    list of fake items in the various registries that could
+    potentially throw off those tests if not accounted for.
+    """
+    return ('Test Fake Plugin',
+            'Test Fake 1D Spectrum List',
+            'Test Fake 1D Spectrum List Concatenated')
+
+
+@tray_registry('test-fake-plugin', label='Test Fake Plugin', category='core')
+class FakePlugin(PluginTemplateMixin):
+    template = ''
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+
+@loader_importer_registry('Test Fake 1D Spectrum List')
+class FakeSpectrumListImporter(SpectrumListImporter):
+    """A fake importer for testing/convenience purposes only.
+    Mostly used to hot-update input for clean code/speed purposes.
+
+    Usage Example:
+    x = FakeSpectrumListImporter(app=deconfigged_helper.app,
+                                 resolver=deconfigged_helper.loaders['object']._obj,
+                                 input=premade_spectrum_list)
+    """
+    template = ''
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.new_default_data_label = None
+
+    @property
+    def input(self):
+        return super().input
+
+    @input.setter
+    def input(self, value):
+        self._input = value
+
+    @property
+    def default_data_label_from_resolver(self):
+        if hasattr(self, 'new_default_data_label'):
+            return self.new_default_data_label
+        return None
+
+
+@loader_importer_registry('Test Fake 1D Spectrum List Concatenated')
+class FakeSpectrumListConcatenatedImporter(SpectrumListConcatenatedImporter):
+    """A fake importer for testing/convenience purposes only.
+    Mostly used to hot-update input for clean code/speed purposes."""
+    template = ''
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.new_default_data_label = None
+
+    @property
+    def input(self):
+        return super().input
+
+    @input.setter
+    def input(self, value):
+        self._input = value
+
+    @property
+    def default_data_label_from_resolver(self):
+        if hasattr(self, 'new_default_data_label'):
+            return self.new_default_data_label
+        return None
+
+
 @pytest.fixture
 def cubeviz_helper():
     return Cubeviz()
@@ -114,6 +200,46 @@ def image_2d_wcs():
                 'CRPIX2': 1, 'CRVAL2': -20.833333059999998})
 
 
+@pytest.fixture
+def source_catalog():
+    """
+    Create a sample source catalog with sources positioned within the
+    coordinate range of the image_2d_wcs fixture.
+
+    The catalog contains 5 sources spread across a 128x128 pixel image field.
+    """
+    # WCS parameters from image_2d_wcs fixture
+    ra_center = 337.5202808  # degrees
+    dec_center = -20.833333  # degrees
+    pixel_scale_deg = 0.0002777777778  # degrees per pixel
+
+    # Create the catalog table
+    catalog = Table()
+
+    # Define source positions spread across the image field
+    catalog['ra'] = [
+        ra_center - 30 * pixel_scale_deg,  # Left side of image
+        ra_center,                          # Center
+        ra_center + 25 * pixel_scale_deg,  # Right side
+        ra_center - 10 * pixel_scale_deg,  # Slightly left of center
+        ra_center + 15 * pixel_scale_deg   # Slightly right of center
+    ] * u.deg
+
+    catalog['dec'] = [
+        dec_center + 20 * pixel_scale_deg,  # Top
+        dec_center - 25 * pixel_scale_deg,  # Bottom
+        dec_center + 10 * pixel_scale_deg,  # Upper right
+        dec_center,                         # Center row
+        dec_center - 15 * pixel_scale_deg   # Lower right
+    ] * u.deg
+
+    catalog['magnitude'] = [12.5, 14.2, 13.8, 15.1, 16.3] * u.mag
+    catalog['flux'] = [1.23e-12, 8.45e-13, 9.87e-13, 6.12e-13, 4.33e-13] * u.erg / (u.cm**2 * u.s)
+    catalog['source_id'] = ['src_001', 'src_002', 'src_003', 'src_004', 'src_005']
+
+    return catalog
+
+
 @pytest.fixture
 def spectral_cube_wcs():
     # A simple spectral cube WCS used by some tests
@@ -200,22 +326,44 @@ def spectrum1d_cube_wcs():
     return wcs
 
 
-def _create_spectrum1d_with_spectral_unit(spectralunit=u.AA):
+def _create_spectrum1d_with_spectral_unit(spectralunit=u.AA, spectral_mask=None, wfss=False,
+                                          exposure='0_0_0_1', source_id='0000'):
     np.random.seed(42)
 
+    if spectral_mask is None:
+        spectral_mask = np.array([False] * SPECTRUM_SIZE)
+
     # We make this first so we don't have to worry about inputting different bounds
-    spec_axis = np.linspace(6000, 8000, SPECTRUM_SIZE) * u.AA
+    spec_axis = Masked(np.linspace(6000, 8000, SPECTRUM_SIZE) * u.AA,
+                       mask=spectral_mask)
     if spectralunit != u.AA:
         spec_axis = spec_axis.to(spectralunit)
 
     flux = (np.random.randn(len(spec_axis.value)) +
             10*np.exp(-0.001*(spec_axis.value-6563)**2) +
             spec_axis.value/500) * u.Jy
+
     uncertainty = StdDevUncertainty(np.abs(np.random.randn(len(spec_axis.value))) * u.Jy)
 
     meta = dict(header=dict(FILENAME="jdaviz-test-file.fits"))
+    if wfss:
+        meta['header'].update(dict(DATAMODL='WFSSMulti', EXPGRPID=exposure))
+        meta.update(dict(source_id=source_id))
 
-    return Spectrum(spectral_axis=spec_axis, flux=flux, uncertainty=uncertainty, meta=meta)
+    # Note, an INFO message pops up informing the user
+    # 'overwriting Masked Quantity's current mask with specified mask. [astropy.nddata.nddata]'
+    # This is expected behavior albeit a nuisance. Is it possible to suppress this message?
+    return Spectrum(spectral_axis=spec_axis, flux=flux, uncertainty=uncertainty,
+                    mask=spectral_mask, meta=meta)
+
+
+@pytest.fixture
+def make_empty_spectrum():
+    return Spectrum(spectral_axis=np.array([]) * u.Hz,
+                    flux=np.array([]) * u.Jy,
+                    uncertainty=StdDevUncertainty(np.array([])),
+                    mask=np.array([]),
+                    meta={})
 
 
 @pytest.fixture
@@ -223,6 +371,35 @@ def spectrum1d():
     return _create_spectrum1d_with_spectral_unit()
 
 
+@pytest.fixture
+def partially_masked_spectrum1d():
+    mask = np.array([False] * SPECTRUM_SIZE)
+    mask[-3:] = True
+    return _create_spectrum1d_with_spectral_unit(spectral_mask=mask)
+
+
+@pytest.fixture
+def wfss_spectrum1d():
+    return _create_spectrum1d_with_spectral_unit(wfss=True)
+
+
+# WFSS may have spectral axes that are partially masked
+# and this is not allowed in specutils
+@pytest.fixture
+def partially_masked_wfss_spectrum1d():
+    mask = np.array([False] * SPECTRUM_SIZE)
+    mask[-3:] = True
+    return _create_spectrum1d_with_spectral_unit(spectral_mask=mask, wfss=True, source_id='1111')
+
+
+@pytest.fixture
+def partially_masked_wfss_spectrum1d_exp1():
+    mask = np.array([False] * SPECTRUM_SIZE)
+    mask[-3:] = True
+    return _create_spectrum1d_with_spectral_unit(spectral_mask=mask, wfss=True,
+                                                 exposure='1_1_1', source_id='1111')
+
+
 @pytest.fixture
 def spectrum1d_nm():
     return _create_spectrum1d_with_spectral_unit(u.nm)
@@ -238,6 +415,18 @@ def spectrum_collection(spectrum1d):
     return result
 
 
+@pytest.fixture
+def premade_spectrum_list(spectrum1d, partially_masked_spectrum1d,
+                          wfss_spectrum1d, partially_masked_wfss_spectrum1d,
+                          partially_masked_wfss_spectrum1d_exp1):
+    return SpectrumList([
+        spectrum1d,
+        partially_masked_spectrum1d,
+        wfss_spectrum1d,
+        partially_masked_wfss_spectrum1d,
+        partially_masked_wfss_spectrum1d_exp1])
+
+
 @pytest.fixture
 def multi_order_spectrum_list(spectrum1d, spectral_orders=10):
     sc = []
@@ -436,6 +625,15 @@ def image_hdu_wcs():
     return _image_hdu_wcs()
 
 
+@pytest.fixture
+def multi_extension_image_hdu_wcs():
+    return fits.HDUList([fits.PrimaryHDU(),
+                         _image_hdu_wcs(),
+                         _image_hdu_nowcs(np.zeros((10, 10)), name='MASK'),
+                         _image_hdu_nowcs(name='ERR'),
+                         _image_hdu_nowcs(name='DQ')])
+
+
 @pytest.fixture
 def image_nddata_wcs():
     return _image_nddata_wcs()
