@@ -9,6 +9,10 @@ from jdaviz.core.loaders.importers import BaseImporterToDataCollection
 class TraceImporter(BaseImporterToDataCollection):
     template_file = __file__, "../to_dc_with_label.vue"
 
+    @staticmethod
+    def _get_supported_viewers():
+        return [{'label': '2D Spectrum', 'reference': 'spectrum-2d-viewer'}]
+
     @property
     def is_valid(self):
         if self.app.config not in ('deconfigged', 'specviz2d'):
@@ -16,9 +20,3 @@ class TraceImporter(BaseImporterToDataCollection):
             return False
         return (isinstance(self.input, Trace)
                 and 'Spectral Extraction' in self.app._jdaviz_helper.plugins)
-
-    @property
-    def default_viewer_reference(self):
-        # returns the registry name of the default viewer
-        # only used if `show_in_viewer=True` and no existing viewers can accept the data
-        return 'spectrum-2d-viewer'
