@@ -17,8 +17,9 @@ from glue_jupyter.bqplot.common.tools import (CheckableTool,
                                               BqplotSelectionTool)
 from bqplot.interacts import BrushSelector, BrushIntervalSelector
 
-from jdaviz.core.events import LineIdentifyMessage, SpectralMarksChangedMessage
-from jdaviz.core.marks import SpectralLine
+from jdaviz.core.events import (LineIdentifyMessage, SpectralMarksChangedMessage,
+                                CatalogSelectClickEventMessage, FootprintSelectClickEventMessage)
+from jdaviz.core.marks import SpectralLine, FootprintOverlay
 
 __all__ = []
 
@@ -154,7 +155,8 @@ class _MatchedZoomMixin:
                             setattr(viewer.state, k, value)
 
     def is_visible(self):
-        return len(self.viewer.jdaviz_app._viewer_store) > 1
+        return (len(self.viewer.jdaviz_app._viewer_store) > 1
+                and len(list(self._iter_matched_viewers())) > 0)
 
 
 @viewer_tool
@@ -339,6 +341,17 @@ class YRangeZoom(_BaseSelectZoom):
         self.viewer.state.y_min, self.viewer.state.y_max = self.interact.selected
 
 
+@viewer_tool
+class ViewerClone(Tool):
+    icon = os.path.join(ICON_DIR, 'viewer_clone')
+    tool_id = 'jdaviz:viewer_clone'
+    action_text = 'Clone viewer'
+    tool_tip = 'Clone this viewer'
+
+    def activate(self):
+        self.viewer.clone_viewer()
+
+
 @viewer_tool
 class SelectLine(CheckableTool, HubListener):
     icon = os.path.join(ICON_DIR, 'line_select.svg')
@@ -381,6 +394,59 @@ class SelectLine(CheckableTool, HubListener):
         return len([m for m in self.viewer.figure.marks if isinstance(m, SpectralLine)]) > 0
 
 
+@viewer_tool
+class SelectCatalogMark(CheckableTool, HubListener):
+    icon = os.path.join(ICON_DIR, 'catalog_select.svg')
+    tool_id = 'jdaviz:selectcatalog'
+    action_text = 'Select/identify source from catalog'
+    tool_tip = 'Select/identify source from catalog'
+
+    def __init__(self, viewer, **kwargs):
+        super().__init__(viewer, **kwargs)
+        self.xs = []
+        self.ys = []
+
+    def activate(self):
+        self.viewer.add_event_callback(self.on_mouse_event,
+                                       events=['click'])
+
+    def deactivate(self):
+        self.viewer.remove_event_callback(self.on_mouse_event)
+
+    def on_mouse_event(self, data):
+        msg = CatalogSelectClickEventMessage(data['domain']['x'], data['domain']['y'], sender=self)
+        self.viewer.session.hub.broadcast(msg)
+
+    def is_visible(self):
+        # NOTE: this assumes Catalogs._marker_name remains fixed at the default of 'catalog_results'
+        return 'catalog_results' in [dci.label for dci in self.viewer.jdaviz_app.data_collection]
+
+
+@viewer_tool
+class SelectFootprintOverlay(CheckableTool, HubListener):
+    icon = os.path.join(ICON_DIR, 'footprint_select.svg')
+    tool_id = 'jdaviz:selectfootprint'
+    action_text = 'Select/identify overlay'
+    tool_tip = 'Select/identify overlay'
+
+    def activate(self):
+        self.viewer.add_event_callback(self.on_mouse_event,
+                                       events=['click'])
+
+    def deactivate(self):
+        self.viewer.remove_event_callback(self.on_mouse_event)
+
+    def on_mouse_event(self, data):
+        msg = FootprintSelectClickEventMessage(data, sender=self)
+        self.viewer.session.hub.broadcast(msg)
+
+    def is_visible(self):
+        return any(
+            isinstance(m, FootprintOverlay) and m.visible
+            for m in self.viewer.figure.marks
+            )
+
+
 @viewer_tool
 class StretchBounds(CheckableTool):
     icon = os.path.join(ICON_DIR, 'stretch_bounds.svg')
@@ -503,7 +569,7 @@ class _BaseSidebarShortcut(Tool):
 class SidebarShortcutPlotOptions(_BaseSidebarShortcut):
     plugin_name = 'g-plot-options'
 
-    icon = os.path.join(ICON_DIR, 'tune.svg')
+    icon = os.path.join(ICON_DIR, 'cog.svg')
     tool_id = 'jdaviz:sidebar_plot'
     action_text = 'Plot Options'
     tool_tip = 'Open plot options plugin in sidebar'
